#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
fabrik
------------

:copyright: (c) 2014-2015 by Fröjd Interactive AB
:license: MIT, see LICENSE for more details.
"""


__title__ = "fabrik"
__version__ = "1.2.2"
__build__ = 122
__license__ = "MIT"
__copyright__ = "Copyright 2014-2015 Fröjd Interactive AB"
